@@ -13,14 +13,15 @@
 #include <hip/hip_fp16.h>
 
 #define NCCL_MAJOR 2
-#define NCCL_MINOR 18
-#define NCCL_PATCH 3
+#define NCCL_MINOR 20
+#define NCCL_PATCH 5
 #define NCCL_SUFFIX ""
 
-#define NCCL_VERSION_CODE 21803
+#define NCCL_VERSION_CODE 22005
 #define NCCL_VERSION(X,Y,Z) (((X) <= 2 && (Y) <= 8) ? (X) * 1000 + (Y) * 100 + (Z) : (X) * 10000 + (Y) * 100 + (Z))
 
 #define RCCL_BFLOAT16 1
+#define RCCL_FLOAT8 1
 #define RCCL_GATHER_SCATTER 1
 #define RCCL_ALLTOALLV 1
 
@@ -98,6 +99,15 @@ typedef struct ncclConfig_v21700 {
 }
 /*! @} */
 
+/* NCCL malloc and free function for all types of NCCL optimizations
+ * (e.g. user buffer registration). The actual allocated size might
+ * be larger than requested due to granularity requirement. */
+ncclResult_t  ncclMemAlloc(void** ptr, size_t size);
+ncclResult_t pncclMemAlloc(void** ptr, size_t size);
+
+ncclResult_t  ncclMemFree(void *ptr);
+ncclResult_t pncclMemFree(void *ptr);
+
 /*! @defgroup   rccl_api_version Version Information
     @details    API call that returns RCCL version
     @{ */
@@ -107,6 +117,7 @@ typedef struct ncclConfig_v21700 {
     @return     Result code. See @ref rccl_result_code for more details.
 
     @param[out] version       Pointer to where version will be stored */
+
 ncclResult_t  ncclGetVersion(int *version);
 /*! @cond       include_hidden */
 ncclResult_t pncclGetVersion(int *version);
@@ -253,11 +264,7 @@ const char*  ncclGetErrorString(ncclResult_t result);
 const char* pncclGetErrorString(ncclResult_t result);
 /*! @endcond */
 
-/*! @brief      Returns mesage on last result that occured.
-    @details    Returns a human-readable message of the last error that occurred.
-    @return     String containing the last result
-
-    @param[in]  comm is currently unused and can be set to NULL */
+/* Returns a human-readable message of the last error that occurred. */
 const char*  ncclGetLastError(ncclComm_t comm);
 /*! @cond       include_hidden */
 const char* pncclGetLastError(ncclComm_t comm);
@@ -313,6 +320,18 @@ ncclResult_t pncclCommUserRank(const ncclComm_t comm, int* rank);
 /*! @endcond */
 /*! @} */
 
+/* Register CUDA buffer for zero-copy operation */
+ncclResult_t  ncclCommRegister(const ncclComm_t comm, void* buff, size_t size, void** handle);
+/*! @cond       include_hidden */
+ncclResult_t pncclCommRegister(const ncclComm_t comm, void* buff, size_t size, void** handle);
+/*! @endcond */
+
+/* Deregister CUDA buffer */
+ncclResult_t  ncclCommDeregister(const ncclComm_t comm, void* handle);
+/*! @cond       include_hidden */
+ncclResult_t pncclCommDeregister(const ncclComm_t comm, void* handle);
+/*! @endcond */
+
 /*! @defgroup   rccl_api_enumerations API Enumerations
     @details    Enumerations used by collective communication calls
     @{ */
@@ -352,7 +371,13 @@ typedef enum { ncclInt8       = 0, ncclChar       = 0,
                ncclFloat32    = 7, ncclFloat      = 7,
                ncclFloat64    = 8, ncclDouble     = 8,
                ncclBfloat16   = 9,
+#if defined(RCCL_FLOAT8)
+               ncclFp8E4M3    = 10,
+               ncclFp8E5M2    = 11,
+               ncclNumTypes   = 12 } ncclDataType_t;
+#else
                ncclNumTypes   = 10 } ncclDataType_t;
+#endif
 /*! @} */
 
 /*! @defgroup   rccl_api_custom_redop Custom Reduction Operator
